@@ -41,14 +41,16 @@ _keyMappings = (
     _(7, 0, 0, kbCtrlG),
     _(8, 0, 0, kbCtrlH),
     _(8, TALT, 0, kbAltBackSpace),
-#    _(9, 0, 0, kbCtrlI),
+    #  _(9, 0, 0, kbCtrlI),
     _(9, 0, 0, kbTab),
-    _(9, 0, MSHIFT, kbShiftTab),
-#    _(10, 0, 0, kbCtrlJ),
+    # _(9, 0, MSHIFT, kbShiftTab),
+    _(curses.KEY_BTAB, 0, 0, kbShiftTab),
+    _(9, 0, MCTRL, kbCtrlTab),
+    # _(10, 0, 0, kbCtrlJ),
     _(10, 0, 0, kbEnter),
     _(11, 0, 0, kbCtrlK),
     _(12, 0, 0, kbCtrlL),
-#    _(13, 0, 0, kbCtrlM),
+    # _(13, 0, 0, kbCtrlM),
     _(13, 0, 0, kbEnter),
     _(14, 0, 0, kbCtrlN),
     _(15, 0, 0, kbCtrlO),
@@ -129,11 +131,19 @@ _keyMappings = (
     _(curses.KEY_END, 0, 0, kbEnd),
     _(curses.KEY_LEFT, 0, MCTRL, kbCtrlLeft),
     _(curses.KEY_RIGHT, 0, MCTRL, kbCtrlRight),
+    _(curses.KEY_UP, 0, MCTRL, kbCtrlUp),
+    _(curses.KEY_DOWN, 0, MCTRL, kbCtrlDown),
     _(curses.KEY_HOME, 0, MCTRL, kbCtrlHome),
     _(curses.KEY_LL, 0, 0, kbCtrlPgDn),
     _(curses.KEY_BEG, 0, 0, kbCtrlPgUp),
     _(curses.KEY_COPY, 0, 0, kbCtrlIns),
     _(curses.KEY_SBEG, 0, 0, kbShiftIns),
+    _(curses.KEY_SHOME, 0, 0, kbShiftHome),
+    _(curses.KEY_SEND, 0, 0, kbShiftEnd),
+    _(curses.KEY_SLEFT, 0, 0, kbShiftLeft),
+    _(curses.KEY_SRIGHT, 0, 0, kbShiftRight),
+    _(curses.KEY_SR, 0, 0, kbShiftUp),
+    _(curses.KEY_SF, 0, 0, kbShiftDown),
 
     _(KEY_F(1), 0, 0, kbF1),
     _(KEY_F(2), 0, 0, kbF2),
