@@ -12,6 +12,7 @@ import select
 import struct
 import subprocess
 import sys
+import threading
 
 from vindauga.constants.command_codes import cmSysRepaint, cmSysResize, cmSysWakeup
 from vindauga.constants.event_codes import (mbLeftButton, mbRightButton, evMouseDown, evMouseUp, meDoubleClick,
@@ -134,6 +135,7 @@ class TScreen:
 
         self.selectPalette()
         self.lockRefresh = 0
+        self.__draw_lock = threading.Lock()
 
     @staticmethod
     def evLength():
@@ -236,7 +238,7 @@ class TScreen:
                 event.mouse.buttons |= mbLeftButton
         else:
             event.mouse.buttons = buttons
-
+        EventQueue.mouse.copy(event.mouse)
         TScreen.putEvent(event)
 
     def handleMouse(self):
@@ -348,7 +350,7 @@ class TScreen:
         modifiers = 0
         if PLATFORM_IS_WINDOWS:
             # Handle ALT+ keys in DOS window
-            if (code & 0x120) == 0x120:
+            if (code & 0x120) == 0x120 and code >= 0x160:
                 code = chr(code - 0x160)
                 keyType = TALT
                 modifiers = 0
@@ -436,7 +438,7 @@ class TScreen:
             self._setScreenSize()
             event.message.command = cmSysResize
             event.what = evCommand
-        elif TScreen.evLength() > 0:
+        elif not TScreen.evQueue.empty():
             event.setFrom(TScreen.evQueue.get())
         elif msAutoTimer.isExpired():
             msAutoTimer.start(DELAY_AUTOCLICK_NEXT)
@@ -514,22 +516,23 @@ class TScreen:
         stdscr.refresh()
 
     def writeRow(self, x, y, src, rowLen):
-        stdscr = self.stdscr
-        stdscr.move(y, x)
-        attributeMap = self.attributeMap
-        attrset = stdscr.attrset
-        addch = stdscr.addch
-        for sc in itertools.islice(src, rowLen):
-            code = chr(sc & 0xFFFF)
-            color = ((sc & 0xFF0000) >> 16) & 0xFF
-            attrset(attributeMap[color])
-            try:
-                addch(code)
-            except curses.error as e:
-                # Writing to the bottom right corner throws an error after it is drawn
-                pass
+        with self.__draw_lock:
+            stdscr = self.stdscr
+            stdscr.move(y, x)
+            attributeMap = self.attributeMap
+            attrset = stdscr.attrset
+            addch = stdscr.addch
+            for sc in itertools.islice(src, rowLen):
+                code = chr(sc & 0xFFFF)
+                color = ((sc & 0xFF0000) >> 16) & 0xFF
+                attrset(attributeMap[color])
+                try:
+                    addch(code)
+                except curses.error as e:
+                    # Writing to the bottom right corner throws an error after it is drawn
+                    pass
 
-        stdscr.move(self.curY, self.curX)
+            stdscr.move(self.curY, self.curX)
 
     def _setScreenSize(self):
         self.screenHeight, self.screenWidth = self.stdscr.getmaxyx()
